; Copyright (c) 2004-2010, Stubbe F. Hviid
;   All rights reserved
;+
; NAME:
;   PRO build_pds_cal_archive, level1_archive_dir, lebel2_archive_dir
;
; PURPOSE:
;   Automatically generated the level2 calibrated image data files from a PDS level1 archive node
;
; CATEGORY:
;   Osiris Archiving
;
; CALLING SEQUENCE:
;  PRO build_pds_cal_archive, level1_archive_dir, lebel2_archive_dir
;
; INPUTS:
;   level1_archive_dir:		Path to the level1 archive node (the RO-?-OSIRIS-1-* folder) - source
;   level2_archive_dir:		Path to the level2 archive node (the RO-?-OSIRIS-2-* folder) - destination
;
; KEYWORD PARAMETERS:
;	None
;
; OUTPUTS:
;   Nothing
;
; RESTRICTIONS:
;   Input sorce data must be in the standart PDS archive structure
;
; EXAMPLE:
;   build_pds_cal_archive, 'c:\temp\RO-X-OSIRIS-1-CVP-COMMISIONING-V1.1', 'c:\temp\RO-X-OSIRIS-2-CVP-COMMISIONING-V1.1'
;
; MODIFICATION HISTORY:
;   Written by:  Stubbe F. Hviid   26/9-2006
;-

PRO find_level1_data_directories, root_dir, rel_dir, dir_list

	print, 'root_dir = ' + root_dir
	print, 'rel_dir = ' + rel_dir


	dirs = file_search(root_dir + '\' + rel_dir + '\*', /TEST_DIRECTORY)

	for i=0, n_elements(dirs)-1 do begin
		if dirs[i] ne '' AND dirs[i] ne '.' AND dirs[i] ne '..' then begin
			fd = p_parse_file_path(dirs[i])
			nreldir = rel_dir + '\' + fd.filename
			find_level1_data_directories, root_dir, nreldir, dir_list
		endif
	endfor

	files = file_search(root_dir + '\' + rel_dir + '\*.IMG', /TEST_REGULAR)

	if files[0] ne '' then begin
		if n_elements(dir_list) eq 0 then dir_list = [rel_dir] else dir_list = [dir_list, rel_dir]
	endif

END

PRO build_pds_cal_archive, level1_archive_dir, level2_archive_dir, level3_archive_dir, _EXTRA=_EXTRA

	level1_archive_dir = strtrim(level1_archive_dir, 2)

	; handle cygwin input path format
	if strmid(level1_archive_dir, 0, 10) eq '/cygdrive/' then begin
		t = strmid(level1_archive_dir, 10, 1) + ':' + strmid(level1_archive_dir, 11)
		level1_archive_dir = t
	endif


	; ----- find input data files -----
	dir_list = ['']
	find_level1_data_directories, level1_archive_dir, 'DATA', dir_list

	if n_elements(dir_list) le 1 then begin
		print, 'Did not find any image files'
		return
	endif

	dir_list = dir_list[1:*]

	; ----- generate output dir name (if required) -----
	if n_elements(level2_archive_dir) eq 0 then begin
		fd = p_parse_file_path(level1_archive_dir)

		if strmid(fd.filename, 0, 3) ne 'RO-' then begin
			print, 'Auto generation of output directory name can only be done on valid OSIRIS dataset input folders'
			return
		endif

		level2_archive_dir = fd.dir + '\' + strmid(fd.filename, 0, 12) + strtrim(string(fix(strmid(fd.filename, 12, 1)+1)), 2) + strmid(fd.filename, 13)
		print, 'Auto generated output directory name: ' + level2_archive_dir

	endif

	if n_elements(level3_archive_dir) eq 0 then begin
		fd = p_parse_file_path(level1_archive_dir)

		if strmid(fd.filename, 0, 3) ne 'RO-' then begin
			print, 'Auto generation of output directory name can only be done on valid OSIRIS dataset input folders'
			return
		endif

		level3_archive_dir = fd.dir + '\' + strmid(fd.filename, 0, 12) + strtrim(string(fix(strmid(fd.filename, 12, 1)+2)), 2) + strmid(fd.filename, 13)
		print, 'Auto generated output directory name: ' + level3_archive_dir

	endif


	; calibrate the found directories
	for i=0, n_elements(dir_list)-1 do begin
		osiris_calibrate_dir, level1_archive_dir + '\' + dir_list[i], $
							  level2_archive_dir + '\' + dir_list[i], $
							  level3_archive_dir + '\' + dir_list[i], $
							  /DELETE_HISTORY, /PDS_ARCHIVE, /CODMAC, /SKIP_LEVEL3, $
							  _EXTRA=_EXTRA
	endfor

	print, dir_list

END
